{% extends 'generic/_base.html' %}
{% load buttons %}
{% load custom_links %}
{% load helpers %}
{% load perms %}
{% load plugins %}
{% load tabs %}
{% load i18n %}
{% load markdown_tags %}

{% comment %}
Blocks:
  - page-header:          Content displayed above the primary page content
    - breadcrumbs:        Breadcrumb list items (HTML <li> elements)
    - object_identifier:  Unique identifier for the object
  - title:                Page title
  - subtitle:             Additional context displayed below the title
  - controls:             Control elements displayed between the header and content
    - control-buttons:    Action buttons (add/edit/delete/etc.)
      - extra_controls:   Any additional action buttons to display
  - tabs:                 Page tabs
  - content:              Primary page content
  - modals:               Any pre-loaded modals

Context:
  - object: The object being viewed
{% endcomment %}

{% block page-header %}
  <div class="container-fluid">
    <div class="d-flex justify-content-between align-items-center mt-2">

    </div>
  </div>
  {{ block.super }}
{% endblock page-header %}

{% block title %}{% endblock %}

{% block subtitle %}

{% endblock subtitle %}

{% block alerts %}
  {% plugin_alerts object %}
{% endblock alerts %}

{% block content %}
  <div class="row mb-3">
    <div class="col col-md-6">
      <div class="card">
        <h5 class="card-header">Create a Virt-lab Modeling Current Run-state</h5>
        <div class="card-body">
          <form action="" method="post" novalidate>
            {% csrf_token %}
            {{ form.as_p }}
            <input type="submit" value="Submit">
            </form>
        </div>
      </div>

      {% if messages %}
        <div class="card">
          <h5 class="card-header">Results</h5>
            <div class="card-body">
                  {% for message in messages %}
                      {% if 'safe' in message.tags %}  {% autoescape off %}{{ message.message }} {% endautoescape %}{% endif %}
                  {% endfor %}
          </div>
      {% endif %}
    </div>
  </div>
{% endblock content %}

{% block modals %}
  {% include 'inc/htmx_modal.html' %}
{% endblock modals %}
